@@ -90,6 +90,7 @@ get_aacinfo(PerlIO *infile, char *file, HV *info, HV *tags)
 */
   
   my_hv_store( info, "audio_offset", newSVuv(audio_offset) );
+  my_hv_store( info, "audio_size", newSVuv(file_size - audio_offset) );
   
   // Parse ID3 at end
   if (id3_size) {
@@ -162,6 +163,10 @@ aac_parse_adts(PerlIO *infile, char *file, off_t audio_size, Buffer *buf, HV *in
   else
     length = 1;
   
+  // Samplerate <= 24000 is AACplus and the samplerate is doubled
+  if (samplerate <= 24000)
+    samplerate *= 2;
+  
   my_hv_store( info, "bitrate", newSVuv(bitrate * 1000) );
   my_hv_store( info, "song_length_ms", newSVuv(length * 1000) );
   my_hv_store( info, "samplerate", newSVuv(samplerate) );
